/*
 * Copyright (c) 2017-2019, Texas Instruments Incorporated
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * *  Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 * *  Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * *  Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
 * OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
/** ============================================================================
 *  @file       CryptoResourceCC26XX.h
 *
 *  @brief      Shared resources to arbitrate access to the keyStore, AES, and SHA2 engine
 *
 */

#ifndef ti_drivers_cryptoutils_sharedresources_CryptoResourceCC26XX__include
#define ti_drivers_cryptoutils_sharedresources_CryptoResourceCC26XX__include

#ifdef __cplusplus
extern "C" {
#endif

#include <stdint.h>
#include <stdbool.h>

#include <ti/drivers/dpl/SemaphoreP.h>

/* Crypto driver semaphore used to synchronize accesses to the keyStore, AES, and SHA2 engine */
extern SemaphoreP_Struct    CryptoResourceCC26XX_accessSemaphore;
extern SemaphoreP_Struct    CryptoResourceCC26XX_operationSemaphore;

extern volatile bool        CryptoResourceCC26XX_pollingFlag;

extern HwiP_Struct          CryptoResourceCC26XX_hwi;



void CryptoResourceCC26XX_constructRTOSObjects(void);
void CryptoResourceCC26XX_destructRTOSObjects(void);
bool CryptoResourceCC26XX_acquireLock();
void CryptoResourceCC26XX_releaseLock();

#ifdef __cplusplus
}
#endif

#endif /* ti_drivers_cryptoutils_sharedresources_CryptoResourceCC26XX__include */
